@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 #
 # Copyright 2021-2022 NXP
+# Copyright 2024-2025 NXP
 #
 # SPDX-License-Identifier: MIT
 
@@ -12,7 +13,7 @@ class FCPlugin(ABC):
     """
     Base plugin of FC
     Detail framework plugins should realize next interfaces
-    `init`, `schedule`, `force_kick_off`
+    `init`, `schedule`, `force_kick_off`, `lock_info`
     """
 
     def __init__(self):
@@ -31,3 +32,7 @@ class FCPlugin(ABC):
     @abstractmethod
     async def force_kick_off(self, resource):
         pass
+
+    @abstractmethod
+    async def lock_info(self, _):
+        pass
