@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright 2021-2022 NXP
+# Copyright 2021-2025 NXP
 #
 # SPDX-License-Identifier: MIT
 
@@ -8,7 +8,9 @@
 import asyncio
 import logging
 
+import prettytable
 from async_lru import alru_cache
+from prettytable import PLAIN_COLUMNS  # pylint: disable=no-name-in-module
 
 from fc_server.core.decorators import (
     check_priority_scheduler,
@@ -43,6 +45,8 @@ class Plugin(FCPlugin, Lava):
         self.seize_cache = {}  # cache to avoid busy seize
         self.job_tags_cache = {}  # cache to store job tags
 
+        self.logger = logging.getLogger("fc_server")
+
     @safe_cache
     def __update_cache(self, cache_name, job_id, value):
         self.__dict__[cache_name][job_id] += value
@@ -89,13 +93,14 @@ class Plugin(FCPlugin, Lava):
                                 del self.seize_cache[job_id]
             await asyncio.sleep(60)
 
-    async def __get_job_tags(self, job_id):
+    async def __get_job_tags(self, job_id, semaphore):
         """
         Return job tag info, issue interface call will return None
         """
 
-        job_info = await self.lava_get_job_info(job_id)
-        return (job_id, job_info["tags"]) if job_info else None
+        async with semaphore:
+            job_info = await self.lava_get_job_info(job_id)
+            return (job_id, job_info["tags"]) if job_info else None
 
     async def __get_device_tags(self, device):
         """
@@ -123,21 +128,13 @@ class Plugin(FCPlugin, Lava):
 
         return await self.lava_get_device_info(device)
 
-    async def __get_device_description(self, device):
-        """
-        Return device description, issue interface call will return None
-        """
-
-        device_info = await self.__get_device_info(device)
-        return (
-            device_info["description"] if device_info else self.lava_default_description
-        )
-
     async def force_kick_off(self, resource):
         """
         Allow coordinator to seize lava resource
         """
 
+        self.logger.info("Lava: force kick off %s", resource)
+
         device_info = await self.lava_get_device_info(resource)
 
         if not device_info:
@@ -188,19 +185,16 @@ class Plugin(FCPlugin, Lava):
             return False, False
 
         if device_info["health"] == "Maintenance":
-            logging.info("%s default in maintenance.", resource)
+            self.logger.info("%s default in maintenance.", resource)
             return True, False
 
         if device_info["health"] == "Retired":
-            logging.info("%s default in retired.", resource)
+            self.logger.info("%s default in retired.", resource)
             return False, False
 
         # ask default framework disconnect this resource
-        logging.info("Disconnect %s from default framework", resource)
-        desc = await self.__get_device_description(resource)
-        if not await self.lava_maintenance_devices(
-            resource, desc=f"{self.device_description_prefix}{desc}"
-        ):
+        self.logger.info("Disconnect %s from default framework", resource)
+        if not await self.lava_maintenance_devices(resource):
             return False, False
 
         device_info = await self.__get_device_info(resource, clear=True)
@@ -215,11 +209,48 @@ class Plugin(FCPlugin, Lava):
         """
 
         # ask default framework connect this resource
-        logging.info("Connect %s to default framework", resource)
-        desc = await self.__get_device_description(resource)
-        return await self.lava_online_devices(
-            resource, desc=desc.split(self.device_description_prefix)[-1]
-        )
+        self.logger.info("Connect %s to default framework", resource)
+        return await self.lava_online_devices(resource)
+
+    async def lock_info(self, driver):
+        """
+        Current lock info of this framework
+        """
+
+        devices = [
+            ["lava", device["current_job"], device["hostname"]]
+            for device in await self.lava_get_devices()
+            if device["hostname"] in driver.managed_resources
+            and device["current_job"] is not None
+        ]
+
+        if len(devices) == 0:
+            return None
+
+        table = prettytable.PrettyTable(align="l")
+        table.set_style(PLAIN_COLUMNS)
+
+        for device in devices:
+            table.add_row(device)
+
+        table.field_names = ["User", "Job", "Place"]
+        table.max_width = 80
+
+        return table.get_string(sortby="Place")
+
+    async def get_comments(self, driver):
+        """
+        Produce comments for lava
+        """
+
+        comments = {
+            device["hostname"]: f"lava#{device['current_job']}"
+            for device in await self.lava_get_devices()
+            if device["hostname"] in driver.managed_resources
+            and device["current_job"] is not None
+        }
+
+        return comments
 
     async def schedule(
         self, driver
@@ -306,7 +337,7 @@ class Plugin(FCPlugin, Lava):
         devices = await self.lava_get_devices()
 
         if not devices:
-            logging.warning(
+            self.logger.warning(
                 "No device fetched from lava server, delay to next scheduling slot"
             )
             return
@@ -328,9 +359,10 @@ class Plugin(FCPlugin, Lava):
                 del self.job_tags_cache[job_id]
 
         # get tags for queued jobs
+        job_tags_semaphore = asyncio.Semaphore(30)
         job_tags_list = await asyncio.gather(
             *[
-                self.__get_job_tags(queued_job["id"])
+                self.__get_job_tags(queued_job["id"], job_tags_semaphore)
                 for queued_job in queued_jobs
                 if queued_job["id"] not in self.job_tags_cache
             ]
@@ -345,7 +377,7 @@ class Plugin(FCPlugin, Lava):
 
             # delay issue job to next scheduling slot
             if job_id not in self.job_tags_cache:
-                logging.warning("Job %s delayed to next scheduling slot", job_id)
+                self.logger.warning("Job %s delayed to next scheduling slot", job_id)
                 continue
 
             candidated_available_devices = managed_resources_category["available"].get(
@@ -416,7 +448,7 @@ class Plugin(FCPlugin, Lava):
                 driver.accept_resource(possible_resource, self)
 
             if not driver.is_default_framework(self):
-                logging.info("Online devices to schedule lava jobs.")
+                self.logger.info("Online devices to schedule lava jobs.")
                 await self.lava_online_devices(*possible_resources)
 
             # cleanup
@@ -431,25 +463,7 @@ class Plugin(FCPlugin, Lava):
         """
 
         if driver.is_default_framework(self):
-            maintenance_devices = [
-                device["hostname"]
-                for device in await self.lava_get_devices()
-                if device["hostname"] in driver.managed_resources
-                and device["health"] in ("Maintenance",)
-            ]
-            recover_devices = [
-                (device, await self.__get_device_description(device))
-                for device in maintenance_devices
-                if (await self.__get_device_description(device)).startswith(
-                    self.device_description_prefix
-                )
-            ]
-            return [
-                self.lava_online_devices(
-                    device, desc=desc.split(self.device_description_prefix)[-1]
-                )
-                for device, desc in recover_devices
-            ]
+            return []
 
         return [
             self.lava_maintenance_devices(device["hostname"])
